# Configure paths for Libpbd
# Based on libsigc++ script by Karl Nelson

dnl Test for Libpbd, and define PBD_CFLAGS and PBD_LIBS
dnl   to be used as follows:
dnl AM_PATH_PBD(MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl
AC_DEFUN(AM_PATH_PBD,
[dnl 
dnl Get the cflags and libraries from the pbd-config script
dnl

dnl
dnl Prefix options
dnl
AC_ARG_WITH(pbd-prefix,
[  --with-pbd-prefix=PREFIX
                          Prefix where libpbd is installed (optional)]
, pbd_config_prefix="$withval", pbd_config_prefix="")

AC_ARG_WITH(pbd-exec-prefix,
[  --with-pbd-exec-prefix=PREFIX 
                          Exec prefix where  libpbd is installed (optional)]
, pbd_config_exec_prefix="$withval", pbd_config_exec_prefix="")

AC_ARG_ENABLE(pbdtest, 
[  --disable-pbdtest     Do not try to compile and run a test libpbd 
                          program],
, enable_pbdtest=yes)

dnl
dnl Prefix handling
dnl
  if test x$pbd_config_exec_prefix != x ; then
     pbd_config_args="$pbd_config_args --exec-prefix=$pbd_config_exec_prefix"
     if test x${PBD_CONFIG+set} != xset ; then
        PBD_CONFIG=$pbd_config_exec_prefix/bin/pbd-config
     fi
  fi
  if test x$pbd_config_prefix != x ; then
     pbd_config_args="$pbd_config_args --prefix=$pbd_config_prefix"
     if test x${PBD_CONFIG+set} != xset ; then
        PBD_CONFIG=$pbd_config_prefix/bin/pbd-config
     fi
  fi

dnl
dnl See if pbd-config is alive
dnl
  AC_PATH_PROG(PBD_CONFIG, pbd-config, no)
  pbd_version_min=$1

dnl
dnl  Version check
dnl
  AC_MSG_CHECKING(for libpbd - version >= $pbd_version_min)
  no_pbd=""
  if test "$PBD_CONFIG" = "no" ; then
    no_pbd=yes
  else
    pbd_version=`$PBD_CONFIG --version`

    PBD_CFLAGS=`$PBD_CONFIG $pbd_config_args --cflags`
    PBD_LIBS=`$PBD_CONFIG $pbd_config_args --libs`

    pbd_major_version=`echo $pbd_version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    pbd_minor_version=`echo $pbd_version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    pbd_micro_version=`echo $pbd_version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    pbd_major_min=`echo $pbd_major_version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    pbd_minor_min=`echo $pbd_minor_version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    pbd_micro_min=`echo $pbd_micro_version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    pbd_version_proper=`expr \
        $pbd_major_version \> $pbd_major_min \| \
        $pbd_major_version \= $pbd_major_min \& \
        $pbd_minor_version \> $pbd_minor_min \| \
        $pbd_major_version \= $pbd_major_min \& \
        $pbd_minor_version \= $pbd_minor_min \& \
        $pbd_micro_version \>= $pbd_micro_min `

    if test "$pbd_version_proper" = "1" ; then
      AC_MSG_RESULT([$pbd_major_version.$pbd_minor_version.$pbd_micro_version])
    else
      AC_MSG_RESULT(no)
      no_pbd=yes
    fi

    if test "X$no_pbd" = "Xyes" ; then
      enable_pbdtest=no
    fi

    AC_LANG_SAVE
    AC_LANG_CPLUSPLUS

dnl
dnl
dnl
    if test "x$enable_pbdtest" = "xyes" ; then
      AC_MSG_CHECKING(if libpbd sane)
      ac_save_CXXFLAGS="$CXXFLAGS"
      ac_save_LIBS="$LIBS"
      CXXFLAGS="$CXXFLAGS $PBD_CFLAGS"
      LIBS="$LIBS $PBD_LIBS"

      rm -f conf.pbdtest
      AC_TRY_RUN([
#include <stdio.h>
#include <pbd/version.h>
#include <pbd/transmitter.h>

Transmitter error(Transmitter::Error);
Transmitter info(Transmitter::Info);
Transmitter warning(Transmitter::Warning);
Transmitter fatal(Transmitter::Fatal);

int main(int argc,char **argv)
  {
   if (pbd_major_version!=$pbd_major_version ||
       pbd_minor_version!=$pbd_minor_version ||
       pbd_micro_version!=$pbd_micro_version)
     { printf("(%d.%d.%d) ",
         pbd_major_version,pbd_minor_version,pbd_micro_version);
       return 1;
     }
  }

],[
  AC_MSG_RESULT(yes)
],[
  AC_MSG_RESULT(no)
  no_pbd=yes
]
,[echo $ac_n "cross compiling; assumed OK... $ac_c"])

       CXXFLAGS="$ac_save_CXXFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi

  dnl
  dnl
  if test "x$no_pbd" = x ; then
     ifelse([$2], , :, [$2])     
  else
     PBD_CFLAGS=""
     PBD_LIBS=""
     ifelse([$3], , :, [$3])
  fi

  AC_LANG_RESTORE

  AC_SUBST(PBD_CFLAGS)
  AC_SUBST(PBD_LIBS)
])

